@@ -1,5 +1,6 @@
 package List::Insertion;
 
+use 5.024000;
 
 use strict;
 use warnings;
@@ -9,7 +10,7 @@ use Data::Combination;
 use Exporter;# qw<import>;
 
 
-our $VERSION = 'v0.1.2';
+our $VERSION = 'v0.1.1';
 
 sub make_search;
 
@@ -39,9 +40,8 @@ sub import {
     $spec->{type}//="string";
     $spec->{duplicate}//="left";
 
-    my ($sub,$code)=make_search $spec;
+    my $sub=make_search $spec;
     *{$package."::".$spec->{name}}=$sub if $sub;
-    #say STDERR $code;
   }
 }
 
@@ -59,13 +59,12 @@ my (\$key, \$array)=\@_;
   \$upper = \@\$array;
 	return 0 unless \$upper;
 
-  use integer;
   # TODO: Run in eval for accessor fall back
   #
-  # local \$_;
+  local \$_;
 	while(\$lower<\$upper){
 		\$middle=(\$upper+\$lower)>>1;
-    (\$key $condition->{$fields{type}}{$fields{duplicate}} \$array->[\$middle]$accessor)
+    \$key $condition->{$fields{type}}{$fields{duplicate}} \$array->[\$middle]$accessor
     $update->{$fields{duplicate}}
   } 
 	\$lower;
@@ -138,13 +137,12 @@ sub make_search {
 
   my $template=Template::Plex->load( \$template_base, {condition=>\%condition, update=>\%update, accessor=>$options->{accessor}}, inject=>['use feature "signatures";']);
   my $code_str=$template->render({duplicate =>$options->{duplicate}, type=>$options->{type}});
-
-  #use feature "say";
-  #use Error::Show;
+  use feature ":all";
+  use Error::Show;
   my $sub=eval($code_str);
   #say STDERR Error::Show::context error=>$@, program=>$code_str if($@ or !$sub);
   #say STDERR $code_str;
-  wantarray?($sub,$code_str):$sub;
+  $sub;
 }
 
 1;
